<?php

namespace Drupal\tome\Normalizer;

use Drupal\serialization\Normalizer\ContentEntityNormalizer as BaseContentEntityNormalizer;

/**
 * Normalizes/denormalizes Drupal content entities into an array structure.
 */
class ContentEntityNormalizer extends BaseContentEntityNormalizer {

  /**
   * {@inheritdoc}
   */
  public function normalize($entity, $format = NULL, array $context = []) {
    $values = parent::normalize($entity, $format, $context);
    /** @var \Drupal\Core\Entity\ContentEntityInterface $entity */
    $entity_type = $entity->getEntityType();
    $id_key = $entity_type->getKey('id');
    // User IDs are important to retain to ensure that User 1 is consistent
    // across rebuilds. We unset the ID key otherwise to make merging easier.
    // Imagine fighting over the next Node ID with an upstream repo! Yuck.
    if ($entity_type->id() !== 'user' && $id_key && isset($values[$id_key])) {
      unset($values[$id_key]);
    }
    $id_key = $entity_type->getKey('revision');
    if ($id_key && isset($values[$id_key])) {
      unset($values[$id_key]);
    }
    return $values;
  }

}
